package readxls;
/*-**********************************************************************
 * File: InvalidCellInfoCollector.java
 * 	(Extracted from
 *	   "$Id$")
 *
 * Abstracts:
 *  This Java source code implements "readxls" package.
 *  "readxls" package reads a excel file (extension ".xls" only),
 *  and create a hashtable contains header cell values or
 *  a list of detaile record cell values.
 *  If package find several invalid data cells. information about
 *  the invalid cells is outputed into a list.
 *  This package depends on JExcelAPI.
 *
 * Copyright (C) 2014 Maoyam Tokyo, Japan (mailto:maoyam@mail.goo.ne.jp)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 *-*********************************************************************/

import readxls.control.CellDefine;
import readxls.type.CellTypeDefine;

/** 不正データ通知.
 * <P>
 * 不正データを見つけた際に、その不正の内容の通知を受ける処理を実装する
 * ためのインタフェース。
 * </P>
 *
 * @author maoyam (maoyam@mail.goo.ne.jp)
 */
public interface InvalidCellInfoCollector {

	/** 不正データ通知.
	 * <P>
	 * 不正データを見つけた際に、その不正の内容の通知を受けるメソッド。
	 * <BR>
	 * InvalidCellInfoCollector インタフェースを実装するクラスは、
	 * このメソッドで不正内容についての情報を処理できる。
	 * </P>
	 * @param rowNo
	 * 不正が見つかった行の行番号 (1～)
	 * @param columnNo
	 * 不正が見つかった列の列番号 (1～)
	 * @param cellDefine
	 * 不正と判定した際のセル定義情報
	 * @param cellType
	 * 不正が見つかったセルの型
	 * @param messageId
	 * 不正の内容についてのメッセージ
	 * @throws ReadXlsException
	 * 不正データの情報を処理した結果、Excel ファイルの読み込みを中断する
	 * 必要がある場合に発生する。
	 * @see readxls.control.CellDefine
	 * @see CellTypeDefine
	 * @see ReadXlsException
	 */
	void notifyInvalidCellInfo(int				rowNo,
								int				columnNo,
								CellDefine		cellDefine,
								CellTypeDefine	cellType,
								String			messageId)
											throws ReadXlsException;

}
