package readxls.control;
/*-**********************************************************************
 * File: HeaderCallable.java
 * 	(Extracted from
 *	   "$Id$")
 *
 * Abstracts:
 *  This Java source code implements "readxls" package.
 *  "readxls" package reads a excel file (extension ".xls" only),
 *  and create a hashtable contains header cell values or
 *  a list of detaile record cell values.
 *  If package find several invalid data cells. information about
 *  the invalid cells is outputed into a list.
 *  This package depends on JExcelAPI.
 *
 * Copyright (C) 2014 Maoyam Tokyo, Japan (mailto:maoyam@mail.goo.ne.jp)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 *-*********************************************************************/

import java.util.Hashtable;

import readxls.ReadXlsException;

/** ヘッダ情報コールバック実装.
 * <P>
 * ヘッダ部のすべての項目を読み込んだ後にコールバックされ、
 * 受け取ったヘッダ情報を処理する手順を実装するインタフェース。
 * </P>
 *
 * @author maoyam (maoyam@mail.goo.ne.jp)
 */
public interface HeaderCallable {

	/** 実装する機能.
	 * <P>
	 * ヘッダ部のすべての項目を読み込んだ後にコールバックされ、
	 * 受け取ったヘッダ情報を処理する手順を実装する。
	 * </P>
	 * @param headers
	 * ヘッダ部から読み込んだヘッダ情報項目のハッシュテーブル
	 * @return
	 * 処理した後のヘッダ項目のハッシュテーブルを返す。
	 * @throws ReadXlsException
	 * ヘッダ情報に不正なデータを検知した場合などに発生する。
	 */
	Hashtable<String, String> call(Hashtable<String, String> headers)
												throws ReadXlsException;

}
