package readxls.control;
/*-**********************************************************************
 * File: HeaderDefine.java
 * 	(Extracted from
 *	   "$Id$")
 *
 * Abstracts:
 *  This Java source code implements "readxls" package.
 *  "readxls" package reads a excel file (extension ".xls" only),
 *  and create a hashtable contains header cell values or
 *  a list of detaile record cell values.
 *  If package find several invalid data cells. information about
 *  the invalid cells is outputed into a list.
 *  This package depends on JExcelAPI.
 *
 * Copyright (C) 2014 Maoyam Tokyo, Japan (mailto:maoyam@mail.goo.ne.jp)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 *-*********************************************************************/

import readxls.XlsHandler;

/** ヘッダ情報構成.
 * <P>
 * 明細情報の内容や種別などをあらわすヘッダ情報を構成するセルの構成を
 * 定義する。
 * </P>
 *
 * @author maoyam (maoyam@mail.goo.ne.jp)
 */
public class HeaderDefine {

	/** ヘッダ情報定義.
	 * <P>
	 * セルの行番号 (1～)
	 * </P>
	 */
	private int rowNo = 0;

	/** ヘッダ情報定義.
	 * <P>
	 * セルの列番号 (1～) と型などの定義
	 * </P>
	 * @see CellDefine
	 */
	private CellDefine cellDefine = null;

	/** getter/setter.
	 * @return
	 * {@link HeaderDefine#rowNo}
	 * を返す。
	 */
	public final int getRowNo() {
		return this.rowNo;
	}

	/** getter/setter.
	 * @param rowNo
	 * {@link HeaderDefine#rowNo}
	 * に設定する値。
	 */
	public final void setRowNo(final int rowNo) {
		this.rowNo = rowNo;
	}

	/** getter/setter.
	 * @return
	 * {@link HeaderDefine#cellDefine}
	 * を返す。
	 * @see CellDefine
	 */
	public final CellDefine getCellDefine() {
		return this.cellDefine;
	}

	/** getter/setter.
	 * @param cellDefine
	 * {@link HeaderDefine#cellDefine}
	 * に設定するセルの定義。
	 * @see CellDefine
	 */
	public final void setCellDefine(final CellDefine cellDefine) {
		this.cellDefine = cellDefine;
	}

	/** コンストラクタ.
	 * @param rowNo
	 * {@link HeaderDefine#rowNo}
	 * に設定する値
	 * @param cellDefine
	 * {@link HeaderDefine#cellDefine}
	 * に設定するセルの定義
	 * @see CellDefine
	 */
	public HeaderDefine(final int rowNo,
						final CellDefine cellDefine) {
		this.rowNo = rowNo;
		this.cellDefine = cellDefine;
	}

	/** 機能.
	 * <P>
	 * ヘッダを構成するセルの定義情報の設定が正当なものであることを
	 * 確認する。
	 * </P>
	 * @param xlsHandler
	 * Excel ファイルを読み込むための依存ライブラリ呼び出し手順の実装
	 * @param localeInfo
	 * ロケール情報
	 * @return
	 * セルの行番号
	 * {@link HeaderDefine#rowNo}
	 * が 1 以上で、セルの定義情報
	 * {@link HeaderDefine#cellDefine}
	 * の設定が正当である場合は、true
	 * を、そうでなければ false を返す。
	 */
	public final boolean isValid(final XlsHandler	xlsHandler,
								final LocaleInfo	localeInfo) {
		return	getRowNo() > 0
				&& getCellDefine().isValidParameters(xlsHandler,
													localeInfo);
	}

}
