package readxls.validate;
/*-**********************************************************************
 * File: Checker.java
 * 	(Extracted from
 *	   "$Id$")
 *
 * Abstracts:
 *  This Java source code implements "readxls" package.
 *  "readxls" package reads a excel file (extension ".xls" only),
 *  and create a hashtable contains header cell values or
 *  a list of detaile record cell values.
 *  If package find several invalid data cells. information about
 *  the invalid cells is outputed into a list.
 *  This package depends on JExcelAPI.
 *
 * Copyright (C) 2014 Maoyam Tokyo, Japan (mailto:maoyam@mail.goo.ne.jp)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 *-*********************************************************************/

import readxls.XlsHandler;

/** 読み込みセルの入力確認.
 * <P>
 * セルの入力値の正当性を確認する手順を実装するためのインタフェース。
 * <BR>
 * セルの型に対応するクラスのインスタンスで入力値は渡される。
 * </P>
 *
 * @author maoyam (maoyam@mail.goo.ne.jp)
 */
public interface Checker {

	/** 機能.
	 * <P>
	 * セルの入力値をセルの型に対応するクラスのインスタンスで渡され、
	 * その正当性を確認する手順を実装する。
	 * </P>
	 * @param xlsHandler
	 * Excel ファイルを読み込むための依存ライブラリ呼び出し手順の実装
	 * @return
	 * セルの入力値が正当であれば true を、そうでなければ false を返す。
	 */
	boolean check(XlsHandler xlsHandler);

}
