package readxls.validate;
/*-**********************************************************************
 * File: DurationChecker.java
 * 	(Extracted from
 *	   "$Id$")
 *
 * Abstracts:
 *  This Java source code implements "readxls" package.
 *  "readxls" package reads a excel file (extension ".xls" only),
 *  and create a hashtable contains header cell values or
 *  a list of detaile record cell values.
 *  If package find several invalid data cells. information about
 *  the invalid cells is outputed into a list.
 *  This package depends on JExcelAPI.
 *
 * Copyright (C) 2014 Maoyam Tokyo, Japan (mailto:maoyam@mail.goo.ne.jp)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 *-*********************************************************************/

import java.util.Date;

import readxls.XlsHandler;

/** 読み込みセルの入力確認.
 * <P>
 * 日付型セルの入力値の範囲をチェックする。
 * </P>
 * @see Checker
 *
 * @author maoyam (maoyam@mail.goo.ne.jp)
 */
public class DurationChecker implements Checker {

	/** 属性.
	 * <P>
	 * 日付の範囲の開始日時
	 * </P>
	 */
	private Date from = null;

	/** 属性.
	 * <P>
	 * 日付の範囲の終了日時
	 * </P>
	 */
	private Date to = null;

	/** 属性.
	 * <P>
	 * セルの入力値が不正だった場合のメッセージ。
	 * </P>
	 */
	private String message = null;

	/** getter/setter.
	 * @return
	 * {@link DurationChecker#from} を返す。
	 */
	private Date getFrom() {
		return from;
	}

	/** getter/setter.
	 * @param from
	 * {@link DurationChecker#from} に指定する日時
	 */
	private void setFrom(final Date from) {
		this.from = from;
	}

	/** getter/setter.
	 * @return
	 * {@link DurationChecker#to} を返す。
	 */
	private Date getTo() {
		return to;
	}

	/** getter/setter.
	 * @param to
	 * {@link DurationChecker#to} に指定する日時
	 */
	private void setTo(final Date to) {
		this.to = to;
	}

	/** getter/setter.
	 * @return
	 * {@link DurationChecker#message} を返す。
	 */
	public final String getMessage() {
		return this.message;
	}

	/** getter/setter.
	 * @param message
	 * {@link DurationChecker#message} に設定するメッセージ。
	 */
	private void setMessage(final String message) {
		this.message = message;
	}

	/** コンストラクタ.
	 * <P>
	 * 日付型セルの入力値の範囲を確認する {@link Checker}
	 * </P>
	 * @param from
	 * {@link DurationChecker#from} に指定する日時
	 * @param to
	 * {@link DurationChecker#to} に指定する日時
	 * @param message
	 * 入力値が範囲外だった場合のメッセージ
	 */
	public DurationChecker(final Date		from,
							final Date		to,
							final String	message) {
		this.setFrom(from);
		this.setTo(to);
		this.setMessage(message);
	}

	/** 機能.
	 * <P>
	 * 日付型のセルの入力値が {@link DurationChecker#from} 以後、
	 * {@link DurationChecker#toString()}
	 * 以前の範囲の日時であることを確認する。
	 * </P>
	 * @param xlsHandler
	 * Excel ファイルを読み込むための依存ライブラリ呼び出し手順の実装
	 * @return
	 * 入力値の日時が範囲内であれば true を、そうでなければ false を返す。
	 */
	@Override
	public final boolean check(final XlsHandler xlsHandler) {
		return ((getFrom() == null
					|| getFrom().compareTo(xlsHandler.getDateCellValue())
																	<= 0)
				&& (getTo() == null
					|| getTo().compareTo(xlsHandler.getDateCellValue())
																	>= 0));
	}

}
